System.register(['./index-205196e6.system.js'], function (exports) {
    'use strict';
    var h, registerInstance, createEvent, Host;
    return {
        setters: [function (module) {
                h = module.h;
                registerInstance = module.r;
                createEvent = module.e;
                Host = module.f;
            }],
        execute: function () {
            /**
             * Removes all key-value entries from the list cache.
             *
             * @private
             * @name clear
             * @memberOf ListCache
             */
            function listCacheClear() {
                this.__data__ = [];
                this.size = 0;
            }
            var _listCacheClear = listCacheClear;
            /**
             * Performs a
             * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
             * comparison between two values to determine if they are equivalent.
             *
             * @static
             * @memberOf _
             * @since 4.0.0
             * @category Lang
             * @param {*} value The value to compare.
             * @param {*} other The other value to compare.
             * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
             * @example
             *
             * var object = { 'a': 1 };
             * var other = { 'a': 1 };
             *
             * _.eq(object, object);
             * // => true
             *
             * _.eq(object, other);
             * // => false
             *
             * _.eq('a', 'a');
             * // => true
             *
             * _.eq('a', Object('a'));
             * // => false
             *
             * _.eq(NaN, NaN);
             * // => true
             */
            function eq(value, other) {
                return value === other || (value !== value && other !== other);
            }
            var eq_1 = eq;
            /**
             * Gets the index at which the `key` is found in `array` of key-value pairs.
             *
             * @private
             * @param {Array} array The array to inspect.
             * @param {*} key The key to search for.
             * @returns {number} Returns the index of the matched value, else `-1`.
             */
            function assocIndexOf(array, key) {
                var length = array.length;
                while (length--) {
                    if (eq_1(array[length][0], key)) {
                        return length;
                    }
                }
                return -1;
            }
            var _assocIndexOf = assocIndexOf;
            /** Used for built-in method references. */
            var arrayProto = Array.prototype;
            /** Built-in value references. */
            var splice = arrayProto.splice;
            /**
             * Removes `key` and its value from the list cache.
             *
             * @private
             * @name delete
             * @memberOf ListCache
             * @param {string} key The key of the value to remove.
             * @returns {boolean} Returns `true` if the entry was removed, else `false`.
             */
            function listCacheDelete(key) {
                var data = this.__data__, index = _assocIndexOf(data, key);
                if (index < 0) {
                    return false;
                }
                var lastIndex = data.length - 1;
                if (index == lastIndex) {
                    data.pop();
                }
                else {
                    splice.call(data, index, 1);
                }
                --this.size;
                return true;
            }
            var _listCacheDelete = listCacheDelete;
            /**
             * Gets the list cache value for `key`.
             *
             * @private
             * @name get
             * @memberOf ListCache
             * @param {string} key The key of the value to get.
             * @returns {*} Returns the entry value.
             */
            function listCacheGet(key) {
                var data = this.__data__, index = _assocIndexOf(data, key);
                return index < 0 ? undefined : data[index][1];
            }
            var _listCacheGet = listCacheGet;
            /**
             * Checks if a list cache value for `key` exists.
             *
             * @private
             * @name has
             * @memberOf ListCache
             * @param {string} key The key of the entry to check.
             * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
             */
            function listCacheHas(key) {
                return _assocIndexOf(this.__data__, key) > -1;
            }
            var _listCacheHas = listCacheHas;
            /**
             * Sets the list cache `key` to `value`.
             *
             * @private
             * @name set
             * @memberOf ListCache
             * @param {string} key The key of the value to set.
             * @param {*} value The value to set.
             * @returns {Object} Returns the list cache instance.
             */
            function listCacheSet(key, value) {
                var data = this.__data__, index = _assocIndexOf(data, key);
                if (index < 0) {
                    ++this.size;
                    data.push([key, value]);
                }
                else {
                    data[index][1] = value;
                }
                return this;
            }
            var _listCacheSet = listCacheSet;
            /**
             * Creates an list cache object.
             *
             * @private
             * @constructor
             * @param {Array} [entries] The key-value pairs to cache.
             */
            function ListCache(entries) {
                var index = -1, length = entries == null ? 0 : entries.length;
                this.clear();
                while (++index < length) {
                    var entry = entries[index];
                    this.set(entry[0], entry[1]);
                }
            }
            // Add methods to `ListCache`.
            ListCache.prototype.clear = _listCacheClear;
            ListCache.prototype['delete'] = _listCacheDelete;
            ListCache.prototype.get = _listCacheGet;
            ListCache.prototype.has = _listCacheHas;
            ListCache.prototype.set = _listCacheSet;
            var _ListCache = ListCache;
            /**
             * Removes all key-value entries from the stack.
             *
             * @private
             * @name clear
             * @memberOf Stack
             */
            function stackClear() {
                this.__data__ = new _ListCache;
                this.size = 0;
            }
            var _stackClear = stackClear;
            /**
             * Removes `key` and its value from the stack.
             *
             * @private
             * @name delete
             * @memberOf Stack
             * @param {string} key The key of the value to remove.
             * @returns {boolean} Returns `true` if the entry was removed, else `false`.
             */
            function stackDelete(key) {
                var data = this.__data__, result = data['delete'](key);
                this.size = data.size;
                return result;
            }
            var _stackDelete = stackDelete;
            /**
             * Gets the stack value for `key`.
             *
             * @private
             * @name get
             * @memberOf Stack
             * @param {string} key The key of the value to get.
             * @returns {*} Returns the entry value.
             */
            function stackGet(key) {
                return this.__data__.get(key);
            }
            var _stackGet = stackGet;
            /**
             * Checks if a stack value for `key` exists.
             *
             * @private
             * @name has
             * @memberOf Stack
             * @param {string} key The key of the entry to check.
             * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
             */
            function stackHas(key) {
                return this.__data__.has(key);
            }
            var _stackHas = stackHas;
            var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};
            function unwrapExports(x) {
                return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
            }
            function createCommonjsModule(fn, basedir, module) {
                return module = {
                    path: basedir,
                    exports: {},
                    require: function (path, base) {
                        return commonjsRequire(path, (base === undefined || base === null) ? module.path : base);
                    }
                }, fn(module, module.exports), module.exports;
            }
            function getCjsExportFromNamespace(n) {
                return n && n['default'] || n;
            }
            function commonjsRequire() {
                throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
            }
            /** Detect free variable `global` from Node.js. */
            var freeGlobal = typeof commonjsGlobal == 'object' && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
            var _freeGlobal = freeGlobal;
            /** Detect free variable `self`. */
            var freeSelf = typeof self == 'object' && self && self.Object === Object && self;
            /** Used as a reference to the global object. */
            var root = _freeGlobal || freeSelf || Function('return this')();
            var _root = root;
            /** Built-in value references. */
            var Symbol = _root.Symbol;
            var _Symbol = Symbol;
            /** Used for built-in method references. */
            var objectProto = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty = objectProto.hasOwnProperty;
            /**
             * Used to resolve the
             * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
             * of values.
             */
            var nativeObjectToString = objectProto.toString;
            /** Built-in value references. */
            var symToStringTag = _Symbol ? _Symbol.toStringTag : undefined;
            /**
             * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
             *
             * @private
             * @param {*} value The value to query.
             * @returns {string} Returns the raw `toStringTag`.
             */
            function getRawTag(value) {
                var isOwn = hasOwnProperty.call(value, symToStringTag), tag = value[symToStringTag];
                try {
                    value[symToStringTag] = undefined;
                    var unmasked = true;
                }
                catch (e) { }
                var result = nativeObjectToString.call(value);
                if (unmasked) {
                    if (isOwn) {
                        value[symToStringTag] = tag;
                    }
                    else {
                        delete value[symToStringTag];
                    }
                }
                return result;
            }
            var _getRawTag = getRawTag;
            /** Used for built-in method references. */
            var objectProto$1 = Object.prototype;
            /**
             * Used to resolve the
             * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
             * of values.
             */
            var nativeObjectToString$1 = objectProto$1.toString;
            /**
             * Converts `value` to a string using `Object.prototype.toString`.
             *
             * @private
             * @param {*} value The value to convert.
             * @returns {string} Returns the converted string.
             */
            function objectToString(value) {
                return nativeObjectToString$1.call(value);
            }
            var _objectToString = objectToString;
            /** `Object#toString` result references. */
            var nullTag = '[object Null]', undefinedTag = '[object Undefined]';
            /** Built-in value references. */
            var symToStringTag$1 = _Symbol ? _Symbol.toStringTag : undefined;
            /**
             * The base implementation of `getTag` without fallbacks for buggy environments.
             *
             * @private
             * @param {*} value The value to query.
             * @returns {string} Returns the `toStringTag`.
             */
            function baseGetTag(value) {
                if (value == null) {
                    return value === undefined ? undefinedTag : nullTag;
                }
                return (symToStringTag$1 && symToStringTag$1 in Object(value))
                    ? _getRawTag(value)
                    : _objectToString(value);
            }
            var _baseGetTag = baseGetTag;
            /**
             * Checks if `value` is the
             * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
             * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
             *
             * @static
             * @memberOf _
             * @since 0.1.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is an object, else `false`.
             * @example
             *
             * _.isObject({});
             * // => true
             *
             * _.isObject([1, 2, 3]);
             * // => true
             *
             * _.isObject(_.noop);
             * // => true
             *
             * _.isObject(null);
             * // => false
             */
            function isObject(value) {
                var type = typeof value;
                return value != null && (type == 'object' || type == 'function');
            }
            var isObject_1 = isObject;
            /** `Object#toString` result references. */
            var asyncTag = '[object AsyncFunction]', funcTag = '[object Function]', genTag = '[object GeneratorFunction]', proxyTag = '[object Proxy]';
            /**
             * Checks if `value` is classified as a `Function` object.
             *
             * @static
             * @memberOf _
             * @since 0.1.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a function, else `false`.
             * @example
             *
             * _.isFunction(_);
             * // => true
             *
             * _.isFunction(/abc/);
             * // => false
             */
            function isFunction(value) {
                if (!isObject_1(value)) {
                    return false;
                }
                // The use of `Object#toString` avoids issues with the `typeof` operator
                // in Safari 9 which returns 'object' for typed arrays and other constructors.
                var tag = _baseGetTag(value);
                return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
            }
            var isFunction_1 = isFunction;
            /** Used to detect overreaching core-js shims. */
            var coreJsData = _root['__core-js_shared__'];
            var _coreJsData = coreJsData;
            /** Used to detect methods masquerading as native. */
            var maskSrcKey = (function () {
                var uid = /[^.]+$/.exec(_coreJsData && _coreJsData.keys && _coreJsData.keys.IE_PROTO || '');
                return uid ? ('Symbol(src)_1.' + uid) : '';
            }());
            /**
             * Checks if `func` has its source masked.
             *
             * @private
             * @param {Function} func The function to check.
             * @returns {boolean} Returns `true` if `func` is masked, else `false`.
             */
            function isMasked(func) {
                return !!maskSrcKey && (maskSrcKey in func);
            }
            var _isMasked = isMasked;
            /** Used for built-in method references. */
            var funcProto = Function.prototype;
            /** Used to resolve the decompiled source of functions. */
            var funcToString = funcProto.toString;
            /**
             * Converts `func` to its source code.
             *
             * @private
             * @param {Function} func The function to convert.
             * @returns {string} Returns the source code.
             */
            function toSource(func) {
                if (func != null) {
                    try {
                        return funcToString.call(func);
                    }
                    catch (e) { }
                    try {
                        return (func + '');
                    }
                    catch (e) { }
                }
                return '';
            }
            var _toSource = toSource;
            /**
             * Used to match `RegExp`
             * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
             */
            var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
            /** Used to detect host constructors (Safari). */
            var reIsHostCtor = /^\[object .+?Constructor\]$/;
            /** Used for built-in method references. */
            var funcProto$1 = Function.prototype, objectProto$2 = Object.prototype;
            /** Used to resolve the decompiled source of functions. */
            var funcToString$1 = funcProto$1.toString;
            /** Used to check objects for own properties. */
            var hasOwnProperty$1 = objectProto$2.hasOwnProperty;
            /** Used to detect if a method is native. */
            var reIsNative = RegExp('^' +
                funcToString$1.call(hasOwnProperty$1).replace(reRegExpChar, '\\$&')
                    .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$');
            /**
             * The base implementation of `_.isNative` without bad shim checks.
             *
             * @private
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a native function,
             *  else `false`.
             */
            function baseIsNative(value) {
                if (!isObject_1(value) || _isMasked(value)) {
                    return false;
                }
                var pattern = isFunction_1(value) ? reIsNative : reIsHostCtor;
                return pattern.test(_toSource(value));
            }
            var _baseIsNative = baseIsNative;
            /**
             * Gets the value at `key` of `object`.
             *
             * @private
             * @param {Object} [object] The object to query.
             * @param {string} key The key of the property to get.
             * @returns {*} Returns the property value.
             */
            function getValue(object, key) {
                return object == null ? undefined : object[key];
            }
            var _getValue = getValue;
            /**
             * Gets the native function at `key` of `object`.
             *
             * @private
             * @param {Object} object The object to query.
             * @param {string} key The key of the method to get.
             * @returns {*} Returns the function if it's native, else `undefined`.
             */
            function getNative(object, key) {
                var value = _getValue(object, key);
                return _baseIsNative(value) ? value : undefined;
            }
            var _getNative = getNative;
            /* Built-in method references that are verified to be native. */
            var Map = _getNative(_root, 'Map');
            var _Map = Map;
            /* Built-in method references that are verified to be native. */
            var nativeCreate = _getNative(Object, 'create');
            var _nativeCreate = nativeCreate;
            /**
             * Removes all key-value entries from the hash.
             *
             * @private
             * @name clear
             * @memberOf Hash
             */
            function hashClear() {
                this.__data__ = _nativeCreate ? _nativeCreate(null) : {};
                this.size = 0;
            }
            var _hashClear = hashClear;
            /**
             * Removes `key` and its value from the hash.
             *
             * @private
             * @name delete
             * @memberOf Hash
             * @param {Object} hash The hash to modify.
             * @param {string} key The key of the value to remove.
             * @returns {boolean} Returns `true` if the entry was removed, else `false`.
             */
            function hashDelete(key) {
                var result = this.has(key) && delete this.__data__[key];
                this.size -= result ? 1 : 0;
                return result;
            }
            var _hashDelete = hashDelete;
            /** Used to stand-in for `undefined` hash values. */
            var HASH_UNDEFINED = '__lodash_hash_undefined__';
            /** Used for built-in method references. */
            var objectProto$3 = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$2 = objectProto$3.hasOwnProperty;
            /**
             * Gets the hash value for `key`.
             *
             * @private
             * @name get
             * @memberOf Hash
             * @param {string} key The key of the value to get.
             * @returns {*} Returns the entry value.
             */
            function hashGet(key) {
                var data = this.__data__;
                if (_nativeCreate) {
                    var result = data[key];
                    return result === HASH_UNDEFINED ? undefined : result;
                }
                return hasOwnProperty$2.call(data, key) ? data[key] : undefined;
            }
            var _hashGet = hashGet;
            /** Used for built-in method references. */
            var objectProto$4 = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$3 = objectProto$4.hasOwnProperty;
            /**
             * Checks if a hash value for `key` exists.
             *
             * @private
             * @name has
             * @memberOf Hash
             * @param {string} key The key of the entry to check.
             * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
             */
            function hashHas(key) {
                var data = this.__data__;
                return _nativeCreate ? (data[key] !== undefined) : hasOwnProperty$3.call(data, key);
            }
            var _hashHas = hashHas;
            /** Used to stand-in for `undefined` hash values. */
            var HASH_UNDEFINED$1 = '__lodash_hash_undefined__';
            /**
             * Sets the hash `key` to `value`.
             *
             * @private
             * @name set
             * @memberOf Hash
             * @param {string} key The key of the value to set.
             * @param {*} value The value to set.
             * @returns {Object} Returns the hash instance.
             */
            function hashSet(key, value) {
                var data = this.__data__;
                this.size += this.has(key) ? 0 : 1;
                data[key] = (_nativeCreate && value === undefined) ? HASH_UNDEFINED$1 : value;
                return this;
            }
            var _hashSet = hashSet;
            /**
             * Creates a hash object.
             *
             * @private
             * @constructor
             * @param {Array} [entries] The key-value pairs to cache.
             */
            function Hash(entries) {
                var index = -1, length = entries == null ? 0 : entries.length;
                this.clear();
                while (++index < length) {
                    var entry = entries[index];
                    this.set(entry[0], entry[1]);
                }
            }
            // Add methods to `Hash`.
            Hash.prototype.clear = _hashClear;
            Hash.prototype['delete'] = _hashDelete;
            Hash.prototype.get = _hashGet;
            Hash.prototype.has = _hashHas;
            Hash.prototype.set = _hashSet;
            var _Hash = Hash;
            /**
             * Removes all key-value entries from the map.
             *
             * @private
             * @name clear
             * @memberOf MapCache
             */
            function mapCacheClear() {
                this.size = 0;
                this.__data__ = {
                    'hash': new _Hash,
                    'map': new (_Map || _ListCache),
                    'string': new _Hash
                };
            }
            var _mapCacheClear = mapCacheClear;
            /**
             * Checks if `value` is suitable for use as unique object key.
             *
             * @private
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
             */
            function isKeyable(value) {
                var type = typeof value;
                return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
                    ? (value !== '__proto__')
                    : (value === null);
            }
            var _isKeyable = isKeyable;
            /**
             * Gets the data for `map`.
             *
             * @private
             * @param {Object} map The map to query.
             * @param {string} key The reference key.
             * @returns {*} Returns the map data.
             */
            function getMapData(map, key) {
                var data = map.__data__;
                return _isKeyable(key)
                    ? data[typeof key == 'string' ? 'string' : 'hash']
                    : data.map;
            }
            var _getMapData = getMapData;
            /**
             * Removes `key` and its value from the map.
             *
             * @private
             * @name delete
             * @memberOf MapCache
             * @param {string} key The key of the value to remove.
             * @returns {boolean} Returns `true` if the entry was removed, else `false`.
             */
            function mapCacheDelete(key) {
                var result = _getMapData(this, key)['delete'](key);
                this.size -= result ? 1 : 0;
                return result;
            }
            var _mapCacheDelete = mapCacheDelete;
            /**
             * Gets the map value for `key`.
             *
             * @private
             * @name get
             * @memberOf MapCache
             * @param {string} key The key of the value to get.
             * @returns {*} Returns the entry value.
             */
            function mapCacheGet(key) {
                return _getMapData(this, key).get(key);
            }
            var _mapCacheGet = mapCacheGet;
            /**
             * Checks if a map value for `key` exists.
             *
             * @private
             * @name has
             * @memberOf MapCache
             * @param {string} key The key of the entry to check.
             * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
             */
            function mapCacheHas(key) {
                return _getMapData(this, key).has(key);
            }
            var _mapCacheHas = mapCacheHas;
            /**
             * Sets the map `key` to `value`.
             *
             * @private
             * @name set
             * @memberOf MapCache
             * @param {string} key The key of the value to set.
             * @param {*} value The value to set.
             * @returns {Object} Returns the map cache instance.
             */
            function mapCacheSet(key, value) {
                var data = _getMapData(this, key), size = data.size;
                data.set(key, value);
                this.size += data.size == size ? 0 : 1;
                return this;
            }
            var _mapCacheSet = mapCacheSet;
            /**
             * Creates a map cache object to store key-value pairs.
             *
             * @private
             * @constructor
             * @param {Array} [entries] The key-value pairs to cache.
             */
            function MapCache(entries) {
                var index = -1, length = entries == null ? 0 : entries.length;
                this.clear();
                while (++index < length) {
                    var entry = entries[index];
                    this.set(entry[0], entry[1]);
                }
            }
            // Add methods to `MapCache`.
            MapCache.prototype.clear = _mapCacheClear;
            MapCache.prototype['delete'] = _mapCacheDelete;
            MapCache.prototype.get = _mapCacheGet;
            MapCache.prototype.has = _mapCacheHas;
            MapCache.prototype.set = _mapCacheSet;
            var _MapCache = MapCache;
            /** Used as the size to enable large array optimizations. */
            var LARGE_ARRAY_SIZE = 200;
            /**
             * Sets the stack `key` to `value`.
             *
             * @private
             * @name set
             * @memberOf Stack
             * @param {string} key The key of the value to set.
             * @param {*} value The value to set.
             * @returns {Object} Returns the stack cache instance.
             */
            function stackSet(key, value) {
                var data = this.__data__;
                if (data instanceof _ListCache) {
                    var pairs = data.__data__;
                    if (!_Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
                        pairs.push([key, value]);
                        this.size = ++data.size;
                        return this;
                    }
                    data = this.__data__ = new _MapCache(pairs);
                }
                data.set(key, value);
                this.size = data.size;
                return this;
            }
            var _stackSet = stackSet;
            /**
             * Creates a stack cache object to store key-value pairs.
             *
             * @private
             * @constructor
             * @param {Array} [entries] The key-value pairs to cache.
             */
            function Stack(entries) {
                var data = this.__data__ = new _ListCache(entries);
                this.size = data.size;
            }
            // Add methods to `Stack`.
            Stack.prototype.clear = _stackClear;
            Stack.prototype['delete'] = _stackDelete;
            Stack.prototype.get = _stackGet;
            Stack.prototype.has = _stackHas;
            Stack.prototype.set = _stackSet;
            var _Stack = Stack;
            var defineProperty = (function () {
                try {
                    var func = _getNative(Object, 'defineProperty');
                    func({}, '', {});
                    return func;
                }
                catch (e) { }
            }());
            var _defineProperty = defineProperty;
            /**
             * The base implementation of `assignValue` and `assignMergeValue` without
             * value checks.
             *
             * @private
             * @param {Object} object The object to modify.
             * @param {string} key The key of the property to assign.
             * @param {*} value The value to assign.
             */
            function baseAssignValue(object, key, value) {
                if (key == '__proto__' && _defineProperty) {
                    _defineProperty(object, key, {
                        'configurable': true,
                        'enumerable': true,
                        'value': value,
                        'writable': true
                    });
                }
                else {
                    object[key] = value;
                }
            }
            var _baseAssignValue = baseAssignValue;
            /**
             * This function is like `assignValue` except that it doesn't assign
             * `undefined` values.
             *
             * @private
             * @param {Object} object The object to modify.
             * @param {string} key The key of the property to assign.
             * @param {*} value The value to assign.
             */
            function assignMergeValue(object, key, value) {
                if ((value !== undefined && !eq_1(object[key], value)) ||
                    (value === undefined && !(key in object))) {
                    _baseAssignValue(object, key, value);
                }
            }
            var _assignMergeValue = assignMergeValue;
            /**
             * Creates a base function for methods like `_.forIn` and `_.forOwn`.
             *
             * @private
             * @param {boolean} [fromRight] Specify iterating from right to left.
             * @returns {Function} Returns the new base function.
             */
            function createBaseFor(fromRight) {
                return function (object, iteratee, keysFunc) {
                    var index = -1, iterable = Object(object), props = keysFunc(object), length = props.length;
                    while (length--) {
                        var key = props[fromRight ? length : ++index];
                        if (iteratee(iterable[key], key, iterable) === false) {
                            break;
                        }
                    }
                    return object;
                };
            }
            var _createBaseFor = createBaseFor;
            /**
             * The base implementation of `baseForOwn` which iterates over `object`
             * properties returned by `keysFunc` and invokes `iteratee` for each property.
             * Iteratee functions may exit iteration early by explicitly returning `false`.
             *
             * @private
             * @param {Object} object The object to iterate over.
             * @param {Function} iteratee The function invoked per iteration.
             * @param {Function} keysFunc The function to get the keys of `object`.
             * @returns {Object} Returns `object`.
             */
            var baseFor = _createBaseFor();
            var _baseFor = baseFor;
            var _cloneBuffer = createCommonjsModule(function (module, exports) {
                /** Detect free variable `exports`. */
                var freeExports = 'object' == 'object' && exports && !exports.nodeType && exports;
                /** Detect free variable `module`. */
                var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;
                /** Detect the popular CommonJS extension `module.exports`. */
                var moduleExports = freeModule && freeModule.exports === freeExports;
                /** Built-in value references. */
                var Buffer = moduleExports ? _root.Buffer : undefined, allocUnsafe = Buffer ? Buffer.allocUnsafe : undefined;
                /**
                 * Creates a clone of  `buffer`.
                 *
                 * @private
                 * @param {Buffer} buffer The buffer to clone.
                 * @param {boolean} [isDeep] Specify a deep clone.
                 * @returns {Buffer} Returns the cloned buffer.
                 */
                function cloneBuffer(buffer, isDeep) {
                    if (isDeep) {
                        return buffer.slice();
                    }
                    var length = buffer.length, result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);
                    buffer.copy(result);
                    return result;
                }
                module.exports = cloneBuffer;
            });
            /** Built-in value references. */
            var Uint8Array = _root.Uint8Array;
            var _Uint8Array = Uint8Array;
            /**
             * Creates a clone of `arrayBuffer`.
             *
             * @private
             * @param {ArrayBuffer} arrayBuffer The array buffer to clone.
             * @returns {ArrayBuffer} Returns the cloned array buffer.
             */
            function cloneArrayBuffer(arrayBuffer) {
                var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
                new _Uint8Array(result).set(new _Uint8Array(arrayBuffer));
                return result;
            }
            var _cloneArrayBuffer = cloneArrayBuffer;
            /**
             * Creates a clone of `typedArray`.
             *
             * @private
             * @param {Object} typedArray The typed array to clone.
             * @param {boolean} [isDeep] Specify a deep clone.
             * @returns {Object} Returns the cloned typed array.
             */
            function cloneTypedArray(typedArray, isDeep) {
                var buffer = isDeep ? _cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
                return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
            }
            var _cloneTypedArray = cloneTypedArray;
            /**
             * Copies the values of `source` to `array`.
             *
             * @private
             * @param {Array} source The array to copy values from.
             * @param {Array} [array=[]] The array to copy values to.
             * @returns {Array} Returns `array`.
             */
            function copyArray(source, array) {
                var index = -1, length = source.length;
                array || (array = Array(length));
                while (++index < length) {
                    array[index] = source[index];
                }
                return array;
            }
            var _copyArray = copyArray;
            /** Built-in value references. */
            var objectCreate = Object.create;
            /**
             * The base implementation of `_.create` without support for assigning
             * properties to the created object.
             *
             * @private
             * @param {Object} proto The object to inherit from.
             * @returns {Object} Returns the new object.
             */
            var baseCreate = (function () {
                function object() { }
                return function (proto) {
                    if (!isObject_1(proto)) {
                        return {};
                    }
                    if (objectCreate) {
                        return objectCreate(proto);
                    }
                    object.prototype = proto;
                    var result = new object;
                    object.prototype = undefined;
                    return result;
                };
            }());
            var _baseCreate = baseCreate;
            /**
             * Creates a unary function that invokes `func` with its argument transformed.
             *
             * @private
             * @param {Function} func The function to wrap.
             * @param {Function} transform The argument transform.
             * @returns {Function} Returns the new function.
             */
            function overArg(func, transform) {
                return function (arg) {
                    return func(transform(arg));
                };
            }
            var _overArg = overArg;
            /** Built-in value references. */
            var getPrototype = _overArg(Object.getPrototypeOf, Object);
            var _getPrototype = getPrototype;
            /** Used for built-in method references. */
            var objectProto$5 = Object.prototype;
            /**
             * Checks if `value` is likely a prototype object.
             *
             * @private
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
             */
            function isPrototype(value) {
                var Ctor = value && value.constructor, proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto$5;
                return value === proto;
            }
            var _isPrototype = isPrototype;
            /**
             * Initializes an object clone.
             *
             * @private
             * @param {Object} object The object to clone.
             * @returns {Object} Returns the initialized clone.
             */
            function initCloneObject(object) {
                return (typeof object.constructor == 'function' && !_isPrototype(object))
                    ? _baseCreate(_getPrototype(object))
                    : {};
            }
            var _initCloneObject = initCloneObject;
            /**
             * Checks if `value` is object-like. A value is object-like if it's not `null`
             * and has a `typeof` result of "object".
             *
             * @static
             * @memberOf _
             * @since 4.0.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
             * @example
             *
             * _.isObjectLike({});
             * // => true
             *
             * _.isObjectLike([1, 2, 3]);
             * // => true
             *
             * _.isObjectLike(_.noop);
             * // => false
             *
             * _.isObjectLike(null);
             * // => false
             */
            function isObjectLike(value) {
                return value != null && typeof value == 'object';
            }
            var isObjectLike_1 = isObjectLike;
            /** `Object#toString` result references. */
            var argsTag = '[object Arguments]';
            /**
             * The base implementation of `_.isArguments`.
             *
             * @private
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is an `arguments` object,
             */
            function baseIsArguments(value) {
                return isObjectLike_1(value) && _baseGetTag(value) == argsTag;
            }
            var _baseIsArguments = baseIsArguments;
            /** Used for built-in method references. */
            var objectProto$6 = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$4 = objectProto$6.hasOwnProperty;
            /** Built-in value references. */
            var propertyIsEnumerable = objectProto$6.propertyIsEnumerable;
            /**
             * Checks if `value` is likely an `arguments` object.
             *
             * @static
             * @memberOf _
             * @since 0.1.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is an `arguments` object,
             *  else `false`.
             * @example
             *
             * _.isArguments(function() { return arguments; }());
             * // => true
             *
             * _.isArguments([1, 2, 3]);
             * // => false
             */
            var isArguments = _baseIsArguments(function () { return arguments; }()) ? _baseIsArguments : function (value) {
                return isObjectLike_1(value) && hasOwnProperty$4.call(value, 'callee') &&
                    !propertyIsEnumerable.call(value, 'callee');
            };
            var isArguments_1 = isArguments;
            /**
             * Checks if `value` is classified as an `Array` object.
             *
             * @static
             * @memberOf _
             * @since 0.1.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is an array, else `false`.
             * @example
             *
             * _.isArray([1, 2, 3]);
             * // => true
             *
             * _.isArray(document.body.children);
             * // => false
             *
             * _.isArray('abc');
             * // => false
             *
             * _.isArray(_.noop);
             * // => false
             */
            var isArray = Array.isArray;
            var isArray_1 = isArray;
            /** Used as references for various `Number` constants. */
            var MAX_SAFE_INTEGER = 9007199254740991;
            /**
             * Checks if `value` is a valid array-like length.
             *
             * **Note:** This method is loosely based on
             * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
             *
             * @static
             * @memberOf _
             * @since 4.0.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
             * @example
             *
             * _.isLength(3);
             * // => true
             *
             * _.isLength(Number.MIN_VALUE);
             * // => false
             *
             * _.isLength(Infinity);
             * // => false
             *
             * _.isLength('3');
             * // => false
             */
            function isLength(value) {
                return typeof value == 'number' &&
                    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
            }
            var isLength_1 = isLength;
            /**
             * Checks if `value` is array-like. A value is considered array-like if it's
             * not a function and has a `value.length` that's an integer greater than or
             * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
             *
             * @static
             * @memberOf _
             * @since 4.0.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
             * @example
             *
             * _.isArrayLike([1, 2, 3]);
             * // => true
             *
             * _.isArrayLike(document.body.children);
             * // => true
             *
             * _.isArrayLike('abc');
             * // => true
             *
             * _.isArrayLike(_.noop);
             * // => false
             */
            function isArrayLike(value) {
                return value != null && isLength_1(value.length) && !isFunction_1(value);
            }
            var isArrayLike_1 = isArrayLike;
            /**
             * This method is like `_.isArrayLike` except that it also checks if `value`
             * is an object.
             *
             * @static
             * @memberOf _
             * @since 4.0.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is an array-like object,
             *  else `false`.
             * @example
             *
             * _.isArrayLikeObject([1, 2, 3]);
             * // => true
             *
             * _.isArrayLikeObject(document.body.children);
             * // => true
             *
             * _.isArrayLikeObject('abc');
             * // => false
             *
             * _.isArrayLikeObject(_.noop);
             * // => false
             */
            function isArrayLikeObject(value) {
                return isObjectLike_1(value) && isArrayLike_1(value);
            }
            var isArrayLikeObject_1 = isArrayLikeObject;
            /**
             * This method returns `false`.
             *
             * @static
             * @memberOf _
             * @since 4.13.0
             * @category Util
             * @returns {boolean} Returns `false`.
             * @example
             *
             * _.times(2, _.stubFalse);
             * // => [false, false]
             */
            function stubFalse() {
                return false;
            }
            var stubFalse_1 = stubFalse;
            var isBuffer_1 = createCommonjsModule(function (module, exports) {
                /** Detect free variable `exports`. */
                var freeExports = 'object' == 'object' && exports && !exports.nodeType && exports;
                /** Detect free variable `module`. */
                var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;
                /** Detect the popular CommonJS extension `module.exports`. */
                var moduleExports = freeModule && freeModule.exports === freeExports;
                /** Built-in value references. */
                var Buffer = moduleExports ? _root.Buffer : undefined;
                /* Built-in method references for those with the same name as other `lodash` methods. */
                var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined;
                /**
                 * Checks if `value` is a buffer.
                 *
                 * @static
                 * @memberOf _
                 * @since 4.3.0
                 * @category Lang
                 * @param {*} value The value to check.
                 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
                 * @example
                 *
                 * _.isBuffer(new Buffer(2));
                 * // => true
                 *
                 * _.isBuffer(new Uint8Array(2));
                 * // => false
                 */
                var isBuffer = nativeIsBuffer || stubFalse_1;
                module.exports = isBuffer;
            });
            /** `Object#toString` result references. */
            var objectTag = '[object Object]';
            /** Used for built-in method references. */
            var funcProto$2 = Function.prototype, objectProto$7 = Object.prototype;
            /** Used to resolve the decompiled source of functions. */
            var funcToString$2 = funcProto$2.toString;
            /** Used to check objects for own properties. */
            var hasOwnProperty$5 = objectProto$7.hasOwnProperty;
            /** Used to infer the `Object` constructor. */
            var objectCtorString = funcToString$2.call(Object);
            /**
             * Checks if `value` is a plain object, that is, an object created by the
             * `Object` constructor or one with a `[[Prototype]]` of `null`.
             *
             * @static
             * @memberOf _
             * @since 0.8.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
             * @example
             *
             * function Foo() {
             *   this.a = 1;
             * }
             *
             * _.isPlainObject(new Foo);
             * // => false
             *
             * _.isPlainObject([1, 2, 3]);
             * // => false
             *
             * _.isPlainObject({ 'x': 0, 'y': 0 });
             * // => true
             *
             * _.isPlainObject(Object.create(null));
             * // => true
             */
            function isPlainObject(value) {
                if (!isObjectLike_1(value) || _baseGetTag(value) != objectTag) {
                    return false;
                }
                var proto = _getPrototype(value);
                if (proto === null) {
                    return true;
                }
                var Ctor = hasOwnProperty$5.call(proto, 'constructor') && proto.constructor;
                return typeof Ctor == 'function' && Ctor instanceof Ctor &&
                    funcToString$2.call(Ctor) == objectCtorString;
            }
            var isPlainObject_1 = isPlainObject;
            /** `Object#toString` result references. */
            var argsTag$1 = '[object Arguments]', arrayTag = '[object Array]', boolTag = '[object Boolean]', dateTag = '[object Date]', errorTag = '[object Error]', funcTag$1 = '[object Function]', mapTag = '[object Map]', numberTag = '[object Number]', objectTag$1 = '[object Object]', regexpTag = '[object RegExp]', setTag = '[object Set]', stringTag = '[object String]', weakMapTag = '[object WeakMap]';
            var arrayBufferTag = '[object ArrayBuffer]', dataViewTag = '[object DataView]', float32Tag = '[object Float32Array]', float64Tag = '[object Float64Array]', int8Tag = '[object Int8Array]', int16Tag = '[object Int16Array]', int32Tag = '[object Int32Array]', uint8Tag = '[object Uint8Array]', uint8ClampedTag = '[object Uint8ClampedArray]', uint16Tag = '[object Uint16Array]', uint32Tag = '[object Uint32Array]';
            /** Used to identify `toStringTag` values of typed arrays. */
            var typedArrayTags = {};
            typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
                typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
                    typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
                        typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
                            typedArrayTags[uint32Tag] = true;
            typedArrayTags[argsTag$1] = typedArrayTags[arrayTag] =
                typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
                    typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
                        typedArrayTags[errorTag] = typedArrayTags[funcTag$1] =
                            typedArrayTags[mapTag] = typedArrayTags[numberTag] =
                                typedArrayTags[objectTag$1] = typedArrayTags[regexpTag] =
                                    typedArrayTags[setTag] = typedArrayTags[stringTag] =
                                        typedArrayTags[weakMapTag] = false;
            /**
             * The base implementation of `_.isTypedArray` without Node.js optimizations.
             *
             * @private
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
             */
            function baseIsTypedArray(value) {
                return isObjectLike_1(value) &&
                    isLength_1(value.length) && !!typedArrayTags[_baseGetTag(value)];
            }
            var _baseIsTypedArray = baseIsTypedArray;
            /**
             * The base implementation of `_.unary` without support for storing metadata.
             *
             * @private
             * @param {Function} func The function to cap arguments for.
             * @returns {Function} Returns the new capped function.
             */
            function baseUnary(func) {
                return function (value) {
                    return func(value);
                };
            }
            var _baseUnary = baseUnary;
            var _nodeUtil = createCommonjsModule(function (module, exports) {
                /** Detect free variable `exports`. */
                var freeExports = 'object' == 'object' && exports && !exports.nodeType && exports;
                /** Detect free variable `module`. */
                var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;
                /** Detect the popular CommonJS extension `module.exports`. */
                var moduleExports = freeModule && freeModule.exports === freeExports;
                /** Detect free variable `process` from Node.js. */
                var freeProcess = moduleExports && _freeGlobal.process;
                /** Used to access faster Node.js helpers. */
                var nodeUtil = (function () {
                    try {
                        // Use `util.types` for Node.js 10+.
                        var types = freeModule && freeModule.require && freeModule.require('util').types;
                        if (types) {
                            return types;
                        }
                        // Legacy `process.binding('util')` for Node.js < 10.
                        return freeProcess && freeProcess.binding && freeProcess.binding('util');
                    }
                    catch (e) { }
                }());
                module.exports = nodeUtil;
            });
            /* Node.js helper references. */
            var nodeIsTypedArray = _nodeUtil && _nodeUtil.isTypedArray;
            /**
             * Checks if `value` is classified as a typed array.
             *
             * @static
             * @memberOf _
             * @since 3.0.0
             * @category Lang
             * @param {*} value The value to check.
             * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
             * @example
             *
             * _.isTypedArray(new Uint8Array);
             * // => true
             *
             * _.isTypedArray([]);
             * // => false
             */
            var isTypedArray = nodeIsTypedArray ? _baseUnary(nodeIsTypedArray) : _baseIsTypedArray;
            var isTypedArray_1 = isTypedArray;
            /**
             * Gets the value at `key`, unless `key` is "__proto__" or "constructor".
             *
             * @private
             * @param {Object} object The object to query.
             * @param {string} key The key of the property to get.
             * @returns {*} Returns the property value.
             */
            function safeGet(object, key) {
                if (key === 'constructor' && typeof object[key] === 'function') {
                    return;
                }
                if (key == '__proto__') {
                    return;
                }
                return object[key];
            }
            var _safeGet = safeGet;
            /** Used for built-in method references. */
            var objectProto$8 = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$6 = objectProto$8.hasOwnProperty;
            /**
             * Assigns `value` to `key` of `object` if the existing value is not equivalent
             * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
             * for equality comparisons.
             *
             * @private
             * @param {Object} object The object to modify.
             * @param {string} key The key of the property to assign.
             * @param {*} value The value to assign.
             */
            function assignValue(object, key, value) {
                var objValue = object[key];
                if (!(hasOwnProperty$6.call(object, key) && eq_1(objValue, value)) ||
                    (value === undefined && !(key in object))) {
                    _baseAssignValue(object, key, value);
                }
            }
            var _assignValue = assignValue;
            /**
             * Copies properties of `source` to `object`.
             *
             * @private
             * @param {Object} source The object to copy properties from.
             * @param {Array} props The property identifiers to copy.
             * @param {Object} [object={}] The object to copy properties to.
             * @param {Function} [customizer] The function to customize copied values.
             * @returns {Object} Returns `object`.
             */
            function copyObject(source, props, object, customizer) {
                var isNew = !object;
                object || (object = {});
                var index = -1, length = props.length;
                while (++index < length) {
                    var key = props[index];
                    var newValue = customizer
                        ? customizer(object[key], source[key], key, object, source)
                        : undefined;
                    if (newValue === undefined) {
                        newValue = source[key];
                    }
                    if (isNew) {
                        _baseAssignValue(object, key, newValue);
                    }
                    else {
                        _assignValue(object, key, newValue);
                    }
                }
                return object;
            }
            var _copyObject = copyObject;
            /**
             * The base implementation of `_.times` without support for iteratee shorthands
             * or max array length checks.
             *
             * @private
             * @param {number} n The number of times to invoke `iteratee`.
             * @param {Function} iteratee The function invoked per iteration.
             * @returns {Array} Returns the array of results.
             */
            function baseTimes(n, iteratee) {
                var index = -1, result = Array(n);
                while (++index < n) {
                    result[index] = iteratee(index);
                }
                return result;
            }
            var _baseTimes = baseTimes;
            /** Used as references for various `Number` constants. */
            var MAX_SAFE_INTEGER$1 = 9007199254740991;
            /** Used to detect unsigned integer values. */
            var reIsUint = /^(?:0|[1-9]\d*)$/;
            /**
             * Checks if `value` is a valid array-like index.
             *
             * @private
             * @param {*} value The value to check.
             * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
             * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
             */
            function isIndex(value, length) {
                var type = typeof value;
                length = length == null ? MAX_SAFE_INTEGER$1 : length;
                return !!length &&
                    (type == 'number' ||
                        (type != 'symbol' && reIsUint.test(value))) &&
                    (value > -1 && value % 1 == 0 && value < length);
            }
            var _isIndex = isIndex;
            /** Used for built-in method references. */
            var objectProto$9 = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$7 = objectProto$9.hasOwnProperty;
            /**
             * Creates an array of the enumerable property names of the array-like `value`.
             *
             * @private
             * @param {*} value The value to query.
             * @param {boolean} inherited Specify returning inherited property names.
             * @returns {Array} Returns the array of property names.
             */
            function arrayLikeKeys(value, inherited) {
                var isArr = isArray_1(value), isArg = !isArr && isArguments_1(value), isBuff = !isArr && !isArg && isBuffer_1(value), isType = !isArr && !isArg && !isBuff && isTypedArray_1(value), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? _baseTimes(value.length, String) : [], length = result.length;
                for (var key in value) {
                    if ((inherited || hasOwnProperty$7.call(value, key)) &&
                        !(skipIndexes && (
                        // Safari 9 has enumerable `arguments.length` in strict mode.
                        key == 'length' ||
                            // Node.js 0.10 has enumerable non-index properties on buffers.
                            (isBuff && (key == 'offset' || key == 'parent')) ||
                            // PhantomJS 2 has enumerable non-index properties on typed arrays.
                            (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
                            // Skip index properties.
                            _isIndex(key, length)))) {
                        result.push(key);
                    }
                }
                return result;
            }
            var _arrayLikeKeys = arrayLikeKeys;
            /**
             * This function is like
             * [`Object.keys`](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
             * except that it includes inherited enumerable properties.
             *
             * @private
             * @param {Object} object The object to query.
             * @returns {Array} Returns the array of property names.
             */
            function nativeKeysIn(object) {
                var result = [];
                if (object != null) {
                    for (var key in Object(object)) {
                        result.push(key);
                    }
                }
                return result;
            }
            var _nativeKeysIn = nativeKeysIn;
            /** Used for built-in method references. */
            var objectProto$a = Object.prototype;
            /** Used to check objects for own properties. */
            var hasOwnProperty$8 = objectProto$a.hasOwnProperty;
            /**
             * The base implementation of `_.keysIn` which doesn't treat sparse arrays as dense.
             *
             * @private
             * @param {Object} object The object to query.
             * @returns {Array} Returns the array of property names.
             */
            function baseKeysIn(object) {
                if (!isObject_1(object)) {
                    return _nativeKeysIn(object);
                }
                var isProto = _isPrototype(object), result = [];
                for (var key in object) {
                    if (!(key == 'constructor' && (isProto || !hasOwnProperty$8.call(object, key)))) {
                        result.push(key);
                    }
                }
                return result;
            }
            var _baseKeysIn = baseKeysIn;
            /**
             * Creates an array of the own and inherited enumerable property names of `object`.
             *
             * **Note:** Non-object values are coerced to objects.
             *
             * @static
             * @memberOf _
             * @since 3.0.0
             * @category Object
             * @param {Object} object The object to query.
             * @returns {Array} Returns the array of property names.
             * @example
             *
             * function Foo() {
             *   this.a = 1;
             *   this.b = 2;
             * }
             *
             * Foo.prototype.c = 3;
             *
             * _.keysIn(new Foo);
             * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
             */
            function keysIn(object) {
                return isArrayLike_1(object) ? _arrayLikeKeys(object, true) : _baseKeysIn(object);
            }
            var keysIn_1 = keysIn;
            /**
             * Converts `value` to a plain object flattening inherited enumerable string
             * keyed properties of `value` to own properties of the plain object.
             *
             * @static
             * @memberOf _
             * @since 3.0.0
             * @category Lang
             * @param {*} value The value to convert.
             * @returns {Object} Returns the converted plain object.
             * @example
             *
             * function Foo() {
             *   this.b = 2;
             * }
             *
             * Foo.prototype.c = 3;
             *
             * _.assign({ 'a': 1 }, new Foo);
             * // => { 'a': 1, 'b': 2 }
             *
             * _.assign({ 'a': 1 }, _.toPlainObject(new Foo));
             * // => { 'a': 1, 'b': 2, 'c': 3 }
             */
            function toPlainObject(value) {
                return _copyObject(value, keysIn_1(value));
            }
            var toPlainObject_1 = toPlainObject;
            /**
             * A specialized version of `baseMerge` for arrays and objects which performs
             * deep merges and tracks traversed objects enabling objects with circular
             * references to be merged.
             *
             * @private
             * @param {Object} object The destination object.
             * @param {Object} source The source object.
             * @param {string} key The key of the value to merge.
             * @param {number} srcIndex The index of `source`.
             * @param {Function} mergeFunc The function to merge values.
             * @param {Function} [customizer] The function to customize assigned values.
             * @param {Object} [stack] Tracks traversed source values and their merged
             *  counterparts.
             */
            function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack) {
                var objValue = _safeGet(object, key), srcValue = _safeGet(source, key), stacked = stack.get(srcValue);
                if (stacked) {
                    _assignMergeValue(object, key, stacked);
                    return;
                }
                var newValue = customizer
                    ? customizer(objValue, srcValue, (key + ''), object, source, stack)
                    : undefined;
                var isCommon = newValue === undefined;
                if (isCommon) {
                    var isArr = isArray_1(srcValue), isBuff = !isArr && isBuffer_1(srcValue), isTyped = !isArr && !isBuff && isTypedArray_1(srcValue);
                    newValue = srcValue;
                    if (isArr || isBuff || isTyped) {
                        if (isArray_1(objValue)) {
                            newValue = objValue;
                        }
                        else if (isArrayLikeObject_1(objValue)) {
                            newValue = _copyArray(objValue);
                        }
                        else if (isBuff) {
                            isCommon = false;
                            newValue = _cloneBuffer(srcValue, true);
                        }
                        else if (isTyped) {
                            isCommon = false;
                            newValue = _cloneTypedArray(srcValue, true);
                        }
                        else {
                            newValue = [];
                        }
                    }
                    else if (isPlainObject_1(srcValue) || isArguments_1(srcValue)) {
                        newValue = objValue;
                        if (isArguments_1(objValue)) {
                            newValue = toPlainObject_1(objValue);
                        }
                        else if (!isObject_1(objValue) || isFunction_1(objValue)) {
                            newValue = _initCloneObject(srcValue);
                        }
                    }
                    else {
                        isCommon = false;
                    }
                }
                if (isCommon) {
                    // Recursively merge objects and arrays (susceptible to call stack limits).
                    stack.set(srcValue, newValue);
                    mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
                    stack['delete'](srcValue);
                }
                _assignMergeValue(object, key, newValue);
            }
            var _baseMergeDeep = baseMergeDeep;
            /**
             * The base implementation of `_.merge` without support for multiple sources.
             *
             * @private
             * @param {Object} object The destination object.
             * @param {Object} source The source object.
             * @param {number} srcIndex The index of `source`.
             * @param {Function} [customizer] The function to customize merged values.
             * @param {Object} [stack] Tracks traversed source values and their merged
             *  counterparts.
             */
            function baseMerge(object, source, srcIndex, customizer, stack) {
                if (object === source) {
                    return;
                }
                _baseFor(source, function (srcValue, key) {
                    stack || (stack = new _Stack);
                    if (isObject_1(srcValue)) {
                        _baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack);
                    }
                    else {
                        var newValue = customizer
                            ? customizer(_safeGet(object, key), srcValue, (key + ''), object, source, stack)
                            : undefined;
                        if (newValue === undefined) {
                            newValue = srcValue;
                        }
                        _assignMergeValue(object, key, newValue);
                    }
                }, keysIn_1);
            }
            var _baseMerge = baseMerge;
            /**
             * This method returns the first argument it receives.
             *
             * @static
             * @since 0.1.0
             * @memberOf _
             * @category Util
             * @param {*} value Any value.
             * @returns {*} Returns `value`.
             * @example
             *
             * var object = { 'a': 1 };
             *
             * console.log(_.identity(object) === object);
             * // => true
             */
            function identity(value) {
                return value;
            }
            var identity_1 = identity;
            /**
             * A faster alternative to `Function#apply`, this function invokes `func`
             * with the `this` binding of `thisArg` and the arguments of `args`.
             *
             * @private
             * @param {Function} func The function to invoke.
             * @param {*} thisArg The `this` binding of `func`.
             * @param {Array} args The arguments to invoke `func` with.
             * @returns {*} Returns the result of `func`.
             */
            function apply(func, thisArg, args) {
                switch (args.length) {
                    case 0: return func.call(thisArg);
                    case 1: return func.call(thisArg, args[0]);
                    case 2: return func.call(thisArg, args[0], args[1]);
                    case 3: return func.call(thisArg, args[0], args[1], args[2]);
                }
                return func.apply(thisArg, args);
            }
            var _apply = apply;
            /* Built-in method references for those with the same name as other `lodash` methods. */
            var nativeMax = Math.max;
            /**
             * A specialized version of `baseRest` which transforms the rest array.
             *
             * @private
             * @param {Function} func The function to apply a rest parameter to.
             * @param {number} [start=func.length-1] The start position of the rest parameter.
             * @param {Function} transform The rest array transform.
             * @returns {Function} Returns the new function.
             */
            function overRest(func, start, transform) {
                start = nativeMax(start === undefined ? (func.length - 1) : start, 0);
                return function () {
                    var args = arguments, index = -1, length = nativeMax(args.length - start, 0), array = Array(length);
                    while (++index < length) {
                        array[index] = args[start + index];
                    }
                    index = -1;
                    var otherArgs = Array(start + 1);
                    while (++index < start) {
                        otherArgs[index] = args[index];
                    }
                    otherArgs[start] = transform(array);
                    return _apply(func, this, otherArgs);
                };
            }
            var _overRest = overRest;
            /**
             * Creates a function that returns `value`.
             *
             * @static
             * @memberOf _
             * @since 2.4.0
             * @category Util
             * @param {*} value The value to return from the new function.
             * @returns {Function} Returns the new constant function.
             * @example
             *
             * var objects = _.times(2, _.constant({ 'a': 1 }));
             *
             * console.log(objects);
             * // => [{ 'a': 1 }, { 'a': 1 }]
             *
             * console.log(objects[0] === objects[1]);
             * // => true
             */
            function constant(value) {
                return function () {
                    return value;
                };
            }
            var constant_1 = constant;
            /**
             * The base implementation of `setToString` without support for hot loop shorting.
             *
             * @private
             * @param {Function} func The function to modify.
             * @param {Function} string The `toString` result.
             * @returns {Function} Returns `func`.
             */
            var baseSetToString = !_defineProperty ? identity_1 : function (func, string) {
                return _defineProperty(func, 'toString', {
                    'configurable': true,
                    'enumerable': false,
                    'value': constant_1(string),
                    'writable': true
                });
            };
            var _baseSetToString = baseSetToString;
            /** Used to detect hot functions by number of calls within a span of milliseconds. */
            var HOT_COUNT = 800, HOT_SPAN = 16;
            /* Built-in method references for those with the same name as other `lodash` methods. */
            var nativeNow = Date.now;
            /**
             * Creates a function that'll short out and invoke `identity` instead
             * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
             * milliseconds.
             *
             * @private
             * @param {Function} func The function to restrict.
             * @returns {Function} Returns the new shortable function.
             */
            function shortOut(func) {
                var count = 0, lastCalled = 0;
                return function () {
                    var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
                    lastCalled = stamp;
                    if (remaining > 0) {
                        if (++count >= HOT_COUNT) {
                            return arguments[0];
                        }
                    }
                    else {
                        count = 0;
                    }
                    return func.apply(undefined, arguments);
                };
            }
            var _shortOut = shortOut;
            /**
             * Sets the `toString` method of `func` to return `string`.
             *
             * @private
             * @param {Function} func The function to modify.
             * @param {Function} string The `toString` result.
             * @returns {Function} Returns `func`.
             */
            var setToString = _shortOut(_baseSetToString);
            var _setToString = setToString;
            /**
             * The base implementation of `_.rest` which doesn't validate or coerce arguments.
             *
             * @private
             * @param {Function} func The function to apply a rest parameter to.
             * @param {number} [start=func.length-1] The start position of the rest parameter.
             * @returns {Function} Returns the new function.
             */
            function baseRest(func, start) {
                return _setToString(_overRest(func, start, identity_1), func + '');
            }
            var _baseRest = baseRest;
            /**
             * Checks if the given arguments are from an iteratee call.
             *
             * @private
             * @param {*} value The potential iteratee value argument.
             * @param {*} index The potential iteratee index or key argument.
             * @param {*} object The potential iteratee object argument.
             * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
             *  else `false`.
             */
            function isIterateeCall(value, index, object) {
                if (!isObject_1(object)) {
                    return false;
                }
                var type = typeof index;
                if (type == 'number'
                    ? (isArrayLike_1(object) && _isIndex(index, object.length))
                    : (type == 'string' && index in object)) {
                    return eq_1(object[index], value);
                }
                return false;
            }
            var _isIterateeCall = isIterateeCall;
            /**
             * Creates a function like `_.assign`.
             *
             * @private
             * @param {Function} assigner The function to assign values.
             * @returns {Function} Returns the new assigner function.
             */
            function createAssigner(assigner) {
                return _baseRest(function (object, sources) {
                    var index = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : undefined, guard = length > 2 ? sources[2] : undefined;
                    customizer = (assigner.length > 3 && typeof customizer == 'function')
                        ? (length--, customizer)
                        : undefined;
                    if (guard && _isIterateeCall(sources[0], sources[1], guard)) {
                        customizer = length < 3 ? undefined : customizer;
                        length = 1;
                    }
                    object = Object(object);
                    while (++index < length) {
                        var source = sources[index];
                        if (source) {
                            assigner(object, source, index, customizer);
                        }
                    }
                    return object;
                });
            }
            var _createAssigner = createAssigner;
            /**
             * This method is like `_.assign` except that it recursively merges own and
             * inherited enumerable string keyed properties of source objects into the
             * destination object. Source properties that resolve to `undefined` are
             * skipped if a destination value exists. Array and plain object properties
             * are merged recursively. Other objects and value types are overridden by
             * assignment. Source objects are applied from left to right. Subsequent
             * sources overwrite property assignments of previous sources.
             *
             * **Note:** This method mutates `object`.
             *
             * @static
             * @memberOf _
             * @since 0.5.0
             * @category Object
             * @param {Object} object The destination object.
             * @param {...Object} [sources] The source objects.
             * @returns {Object} Returns `object`.
             * @example
             *
             * var object = {
             *   'a': [{ 'b': 2 }, { 'd': 4 }]
             * };
             *
             * var other = {
             *   'a': [{ 'c': 3 }, { 'e': 5 }]
             * };
             *
             * _.merge(object, other);
             * // => { 'a': [{ 'b': 2, 'c': 3 }, { 'd': 4, 'e': 5 }] }
             */
            var merge = _createAssigner(function (object, source, srcIndex) {
                _baseMerge(object, source, srcIndex);
            });
            var merge_1 = merge;
            var parseStyles = function (styles) { return styles
                .split(';')
                .filter(function (style) { return style.split(':')[0] && style.split(':')[1]; })
                .map(function (style) { return [
                style.split(':')[0].trim().replace(/-./g, function (c) { return c.substr(1).toUpperCase(); }),
                style.split(':')[1].trim()
            ]; })
                .reduce(function (styleObj, style) {
                var _a;
                return (Object.assign(Object.assign({}, styleObj), (_a = {}, _a[style[0]] = style[1], _a)));
            }, {}); };
            // tslint:disable-next-line: variable-name
            var SVGContent = function (_a) {
                var elements = _a.elements, extra = _a.extra;
                return elements.map(function (el) {
                    // Copy attributes, since they're going to be modified.  If the original
                    // attributes are referenced, then any modifications are lasting.
                    var attrs = Object.assign({}, el.attrs);
                    if (attrs.hasOwnProperty('xlink:href')) {
                        attrs['xlinkHref'] = attrs['xlink:href'];
                        delete attrs['xlink:href'];
                    }
                    if (extra !== undefined && extra.hasOwnProperty(el.attrs.id)) {
                        // Attrs can have properties that are objects (class and style), so do
                        // a deep merge when adding any extra attributes.
                        attrs = merge_1(attrs, extra[el.attrs.id]);
                    }
                    if (attrs.hasOwnProperty('style') && typeof attrs.style === 'string') {
                        attrs.style = parseStyles(attrs.style);
                    }
                    return (h(el.elem, Object.assign({}, attrs), el.content ?
                        el.content.map(function (content) { return (content.text); }) : undefined));
                });
            };
            var SVGDefs = function () { return (h("defs", { id: "defs" }, h("symbol", { id: "SYM_Elevator" }, h("use", { id: "use39", xlinkHref: "#SYM_Outline" }), h("path", { id: "pElevator", d: "M19 5l-.53.529-2.1-2.093V8h-.74V3.436l-2.1 2.096L13 5l3-3zm-8 0l-.53-.529-2.095 2.093V2h-.75v4.564L5.532 4.467 5 5l3 3zM6.5 9C5.678 9 5 9.678 5 10.5v10c0 .82.678 1.5 1.5 1.5h11c.82 0 1.5-.68 1.5-1.5v-10c0-.822-.68-1.5-1.5-1.5zm0 1h11c.29 0 .5.21.5.5v10c0 .29-.21.5-.5.5h-11c-.286 0-.5-.21-.5-.5v-10c0-.29.214-.5.5-.5zm9 2a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1zm-1 1.5a3 3 0 00-1.73.56.5.5 0 00-.27.44v3h1V21h2v-3.5h1v-3a.5.5 0 00-.26-.44 3 3 0 00-1.74-.56zm-4-1.5a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1zm-1 1.5a3 3 0 00-1.73.56.5.5 0 00-.27.44v3h1V21h2v-3.5h1v-3a.5.5 0 00-.26-.44 3 3 0 00-1.74-.56z" })), h("symbol", { id: "SYM_Outline" }, h("path", { id: "pOutline", fill: "#fff", stroke: "#000", "stroke-width": ".5", d: "M1 3c0-1.25.75-2 2-2h18c1.25 0 2 .75 2 2v18c0 1.25-.75 2-2 2H3c-1.25 0-2-.75-2-2z" })), h("symbol", { id: "SYM_Wash_F" }, h("use", { id: "use7", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashF", d: "M11.99 6.999c-.71.002-1.37.382-1.72 1.001-.845 2.64-1.604 6.68-2.273 9h1.995v5H14v-5h2c-.78-2.69-1.58-6.66-2.28-9a1.986 1.986 0 00-1.73-1.001zM14 4a2.005 2.005 0 01-4.008 0c0-1.104.898-2 1.998-2C13.1 2 14 2.896 14 4z" })), h("symbol", { id: "SYM_Wash_FA" }, h("use", { id: "use11", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashFA", d: "M9.317 5H10v14h-.683zM4.8 8.5a1.406 1.406 0 00-1.211.7C3 11.05 2.468 13.88 2 15.5h1.4V19h2.8v-3.5h1.4c-.539-1.88-1.099-4.66-1.589-6.3A1.406 1.406 0 004.8 8.5zm1.4-2.1a1.4 1.4 0 01-1.4 1.4 1.4 1.4 0 01-1.4-1.4A1.4 1.4 0 014.8 5a1.4 1.4 0 011.4 1.4zm12.3 0a1.4 1.4 0 01-1.4 1.4 1.4 1.4 0 01-1.4-1.4A1.4 1.4 0 0117.1 5a1.4 1.4 0 011.4 1.4zm3.5 6.3v-1.4c-1.08.01-2.16-.52-2.85-1.28l-.9-1.002c-.23-.267-.77-.547-1.28-.504-.74.063-1.27.714-1.27 1.449V14.1c0 .77.63 1.4 1.4 1.4h3.5V19H22v-3.85c0-.77-.63-1.4-1.4-1.4h-2.1v-2.41c.9.74 2.27 1.35 3.5 1.36zm-4.32 3.5A2.1 2.1 0 1115 13.52v-1.45c-1.6.32-2.8 1.74-2.8 3.43 0 1.93 1.57 3.5 3.5 3.5 1.69 0 3.11-1.2 3.43-2.8z" })), h("symbol", { id: "SYM_Wash_M" }, h("use", { id: "use15", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashM", d: "M14 4c0 1.104-.89 2-2 2-1.1 0-2-.896-2-2s.9-2 2-2c1.11 0 2 .896 2 2zm-2 3c-1.24.005-2.425.427-3.459 1.113C8.23 8.319 8 8.627 8 9v6h2v7h4v-7h2V8.999c0-.37-.22-.675-.53-.882C14.44 7.427 13.25 7.003 12 7z" })), h("symbol", { id: "SYM_Wash_MA" }, h("use", { id: "use19", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashMA", d: "M9.317 5H10v14h-.683zM18.5 6.4a1.4 1.4 0 01-1.4 1.4 1.4 1.4 0 01-1.4-1.4A1.4 1.4 0 0117.1 5a1.4 1.4 0 011.4 1.4zm3.5 6.3v-1.4c-1.08.01-2.16-.52-2.85-1.28l-.9-1.002c-.27-.323-.68-.564-1.28-.504-.74.063-1.27.714-1.27 1.449V14.1c0 .77.63 1.4 1.4 1.4h3.5V19H22v-3.85c0-.77-.63-1.4-1.4-1.4h-2.1v-2.41c.9.74 2.27 1.35 3.5 1.36zm-4.32 3.5A2.1 2.1 0 1115 13.52v-1.45c-1.6.32-2.8 1.74-2.8 3.43 0 1.93 1.57 3.5 3.5 3.5 1.69 0 3.11-1.2 3.43-2.8zM6.2 6.4a1.4 1.4 0 01-1.4 1.4 1.4 1.4 0 01-1.4-1.4A1.4 1.4 0 014.8 5a1.4 1.4 0 011.4 1.4zM4.8 8.5a4.2 4.2 0 00-2.423.779A.7.7 0 002 9.9v4.2h1.4V19h2.8v-4.9h1.4V9.9a.7.7 0 00-.371-.618A4.2 4.2 0 004.8 8.5z" })), h("symbol", { id: "SYM_Wash_U" }, h("use", { id: "use23", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashU", d: "M5.807 7.241a5.712 5.712 0 00-3.293 1.066.948.948 0 00-.514.838v5.715h1.903v6.66h3.808v-6.66h1.904V9.145a.97.97 0 00-.495-.838 5.765 5.765 0 00-3.313-1.066zm1.904-2.855a1.904 1.904 0 11-3.809-.003 1.904 1.904 0 013.809.003zm12.369 0c0 1.05-.85 1.903-1.9 1.903-1.05 0-1.9-.853-1.9-1.903 0-1.052.85-1.905 1.9-1.905 1.05 0 1.9.853 1.9 1.905zm-1.9 2.855c-.67.003-1.29.364-1.64.952-.79 2.517-1.52 6.347-2.16 8.557h1.9v4.77h3.8v-4.77H22c-.73-2.54-1.5-6.32-2.16-8.557a1.943 1.943 0 00-1.66-.952zm-6.64-4.76h.93V21.52h-.93z" })), h("symbol", { id: "SYM_Wash_UA" }, h("use", { id: "use27", xlinkHref: "#SYM_Outline" }), h("path", { id: "pWashUA", d: "M13.51 7H14v10h-.49zM7.012 7H7.5v10h-.488zM10.5 9.5c-.35.001-.685.191-.865.5-.42 1.32-.8 3.34-1.135 4.5h1V17h2v-2.5h1c-.38-1.34-.78-3.33-1.13-4.5a1.02 1.02 0 00-.87-.5zm1-1.5a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1zm8 0a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1zm2.5 4.5v-1c-.77.01-1.55-.37-2.04-.91l-.64-.72c-.2-.229-.44-.409-.91-.36-.53.045-.91.51-.91 1.04v2.95c0 .55.45 1 1 1H21V17h1v-2.75c0-.55-.45-1-1-1h-1.5v-1.72c.64.53 1.62.97 2.5.97zM18.91 15A1.498 1.498 0 1117 13.09v-1.04A2.5 2.5 0 1019.95 15zM5 8a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1zM4 9.5a3 3 0 00-1.73.56.5.5 0 00-.27.44v3h1V17h2v-3.5h1v-3a.5.5 0 00-.265-.44A3 3 0 004 9.5z" })), h("symbol", { id: "SYM_Accessible" }, h("use", { id: "use31", xlinkHref: "#SYM_Outline" }), h("path", { id: "pAccess", d: "M19 13v-2c-1.54.02-3.09-.75-4.07-1.83l-1.29-1.43c-.16-.228-.95-.804-1.83-.72C10.76 7.11 10 8.04 10 9.09V15c0 1.1.9 2 2 2h5v5h2v-5.5c0-1.1-.9-2-2-2h-3v-3.45c1.29 1.07 3.25 1.94 5 1.95zm-6.17 5c-.41 1.16-1.52 2-2.83 2-1.66 0-3-1.34-3-3 0-1.31.84-2.41 2-2.83V12.1a5 5 0 105.9 5.9zM14 4c0 1.105-.9 2-2 2s-2-.895-2-2 .9-2 2-2 2 .895 2 2z" })), h("symbol", { id: "SYM_Accessible_Ramp" }, h("use", { id: "use35", xlinkHref: "#SYM_Outline" }), h("path", { id: "pAccessRamp", d: "M2 22h20v-5L2 22m13.2-11.2V9.2c-1.23.016-2.47-.6-3.26-1.464l-1.03-1.144c-.29-.344-.74-.619-1.462-.576C8.608 6.088 8 6.832 8 7.672V12.4c0 .88.72 1.6 1.6 1.6h4v4h1.6v-4.4c0-.88-.72-1.6-1.6-1.6h-2.4V9.24c1.03.86 2.6 1.55 4 1.56zm-4.94 4A2.391 2.391 0 018 16.4a2.398 2.398 0 11-.8-4.66v-1.66a4 4 0 104.72 4.72zm.94-11.2a1.6 1.6 0 01-1.6 1.6A1.6 1.6 0 018 3.6 1.6 1.6 0 019.6 2a1.6 1.6 0 011.6 1.6z" })), h("symbol", { id: "SYM_Comp" }, h("path", { id: "pComp", d: "M20 18c1.1 0 1.99-.9 1.99-2L22 6c0-1.1-.9-2-2-2H4c-1.1 0-2 .9-2 2v10c0 1.1.9 2 2 2H0v2h24v-2h-4zM4 6h16v10H4V6z" })), h("symbol", { id: "SYM_Reload_Cash" }, h("use", { id: "use43", xlinkHref: "#SYM_Outline" }), h("path", { id: "pReloadCash", d: "M17 8v3h-3v2h3v3h2v-3h3v-2h-3V8zm-9.52 2.9c-2.27-.59-3-1.2-3-2.15 0-1.09 1.01-1.85 2.7-1.85 1.78 0 2.44.85 2.5 2.1h2.21c-.07-1.72-1.12-3.3-3.21-3.81V3h-3v2.16c-1.94.42-3.5 1.68-3.5 3.61 0 2.31 1.91 3.46 4.7 4.13 2.5.6 3 1.48 3 2.41 0 .69-.49 1.79-2.7 1.79-2.06 0-2.87-.92-2.98-2.1H2c.12 2.19 1.76 3.42 3.68 3.83V21h3v-2.15c1.95-.37 3.5-1.5 3.5-3.55 0-2.84-2.43-3.81-4.7-4.4z" })), h("symbol", { id: "SYM_Kiosk" }, h("use", { id: "use47", xlinkHref: "#SYM_Outline" }), h("path", { id: "pKiosk", d: "M3 4a1 1 0 00-1 1v14a1 1 0 001 1h18a1 1 0 001-1V5a1 1 0 00-1-1zm1 2h16v12H4zm8.98 6.05V10.3c0-.644.53-1.167 1.17-1.167.64 0 1.17.523 1.17 1.167v1.75c.56-.38.93-1.02.93-1.75 0-1.162-.94-2.1-2.1-2.1-1.16 0-2.1.938-2.1 2.1 0 .73.37 1.37.93 1.75zm4.6 2.16l-2.12-1.06a.751.751 0 00-.26-.05h-.35v-2.8c0-.387-.31-.7-.7-.7-.39 0-.7.313-.7.7v5.01l-1.6-.33c-.04-.01-.07-.02-.11-.02a.49.49 0 00-.37.16l-.37.37 2.31 2.3c.12.13.3.21.49.21h3.17c.35 0 .62-.26.67-.6l.35-2.46c.01-.03.01-.06.01-.09 0-.29-.18-.54-.42-.64z" })), h("symbol", { id: "SYM_Recharge_Power" }, h("use", { id: "use51", xlinkHref: "#SYM_Outline" }), h("path", { id: "pRechargePower", d: "M15.67 4H14V2h-4v2H8.33C7.6 4 7 4.6 7 5.33v15.33C7 21.4 7.6 22 8.33 22h7.33c.74 0 1.34-.6 1.34-1.33V5.33C17 4.6 16.4 4 15.67 4zM11 20v-5.5H9L13 7v5.5h2z" })), h("symbol", { id: "SYM_Printer" }, h("use", { id: "use55", xlinkHref: "#SYM_Outline" }), h("path", { id: "pPrinter", d: "M19 8H5c-1.66 0-3 1.34-3 3v6h4v4h12v-4h4v-6c0-1.66-1.34-3-3-3zm-3 11H8v-5h8zm3-7c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm-1-9H6v4h12z" })), h("symbol", { id: "SYM_Phone" }, h("use", { id: "use59", xlinkHref: "#SYM_Outline" }), h("path", { id: "pPhone", d: "M15 2v3h-3v4h3v3h4V9h3V5h-3V2zm1 1h2v3h3v2h-3v3h-2V8h-3V6h3zM6.615 17.39a16.22 16.22 0 008.765 4.49 2.704 2.704 0 002.17-.25l-3.76-3.77-.48.48-7.651-7.65.478-.48-3.76-3.756a2.704 2.704 0 00-.268 2.138 16.22 16.22 0 004.506 8.798zm11.475 3.82L20 19.3l-1.91-1.91-1.91-1.92-1.68 1.68-.24.24zM6.615 9.737l.239-.239 1.673-1.673-1.912-1.912-.956-.956L4.703 4 2.791 5.913z" })), h("symbol", { id: "SYM_Change_Table" }, h("use", { id: "use63", xlinkHref: "#SYM_Outline" }), h("path", { id: "pChangeTable", d: "M11.12 17.12l-1.456 1.46 1.766 1.77a.996.996 0 11-1.41 1.41l-2.831-2.83a1.5 1.5 0 010-2.12L9 15zm1.76 0l1.46 1.46-1.77 1.77a.996.996 0 101.41 1.41l2.83-2.83c.59-.58.59-1.53 0-2.12L15 15zM9.99 8a.994.994 0 00-.684.301L5.325 12.27c-.977.94.47 2.38 1.408 1.41l2.281-2.28v2.57h5.976V11.4l2.28 2.28c.94.97 2.38-.47 1.4-1.41l-3.98-3.969A.971.971 0 0013.98 8zm4.51-3.5A2.5 2.5 0 0112 7a2.5 2.5 0 01-2.5-2.5A2.5 2.5 0 0112 2a2.5 2.5 0 012.5 2.5z" })), h("symbol", { id: "SYM_Accessible_Elevator" }, h("use", { id: "use67", xlinkHref: "#SYM_Outline" }), h("path", { id: "pAccessElevator", d: "M19 5l-.53.529-2.1-2.093V8h-.74V3.436l-2.1 2.096L13 5l3-3zm-8 0l-.53-.529-2.095 2.093V2h-.75v4.564L5.532 4.467 5 5l3 3zM6.5 9C5.678 9 5 9.678 5 10.5v10c0 .82.678 1.5 1.5 1.5h11c.82 0 1.5-.68 1.5-1.5v-10c0-.822-.68-1.5-1.5-1.5zm0 1h11c.29 0 .5.21.5.5v10c0 .29-.21.5-.5.5h-11c-.286 0-.5-.21-.5-.5v-10c0-.29.214-.5.5-.5zm9 6.5v-1c-.77.01-1.54-.37-2.03-.91l-.65-.72c-.2-.24-.47-.39-.91-.36-.53.05-.91.51-.91 1.04v2.95c0 .55.45 1 1 1h2.5V21h1v-2.75c0-.55-.45-1-1-1H13v-1.72c.65.53 1.63.97 2.5.97zM12.41 19a1.498 1.498 0 01-2.91-.5c0-.66.42-1.2 1-1.42v-1.03A2.5 2.5 0 1013.45 19zm.59-7a1 1 0 01-1 1 1 1 0 01-1-1 1 1 0 011-1 1 1 0 011 1z" })), h("symbol", { id: "SYM_Refill_Water" }, h("use", { id: "use71", xlinkHref: "#SYM_Outline" }), h("path", { id: "pRefillWater", d: "M7 2a2 2 0 00-2 2 2 2 0 002 2 2 2 0 002-2 2 2 0 00-2-2zm9 4.25c-1.25 0-2.5 1.028-2.5 2.75h1c0-1.278.75-1.75 1.5-1.75s1.5.472 1.5 1.75v6H13c-1.1 0-2 .9-2 2l6 4h2v-6h-.5V9c0-1.722-1.25-2.75-2.5-2.75zM7 7c-1 0-2 .892-2 2v5c0 .74.404 1.38 1 1.72V22h2v-6.28c.596-.34 1-.98 1-1.72v-3.03c1.72 1.4 3 2.03 4 2.03v1h2v-4h-2v1c-1 0-2.17-.71-4.359-3.143C8.277 7.47 8 7 7 7z" })), h("symbol", { id: "SYM_Stairs" }, h("use", { id: "use75", xlinkHref: "#SYM_Outline" }), h("path", { id: "pStairs", d: "M12 3.708v3.949h1V2H7.343v1.004l3.947-.003-8.289 8.289.003-3.947H2V13h5.657v-1H3.708zM17 5v3h-3v3h-3v3H8v3H5v3H2v2h5v-3h3v-3h3v-3h3v-3h3V7h3V5h-3z" })), h("symbol", { id: "SYM_Info" }, h("use", { id: "use79", xlinkHref: "#SYM_Outline" }), h("path", { id: "pInfo", d: "M11 17h2v-6h-2zm1-15C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8zM11 9h2V7h-2z" })))); };
            var floorplanCss = ":host{display:block;position:absolute;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}:host(:not([show-computers])) .rl-svg__g--computers{visibility:hidden}:host(:not([show-shelves])) .rl-svg__g--shelves{visibility:hidden}:host[show-computers] .rl-svg__g--computers,:host[show-shelves] .rl-svg__g-shelves{visibility:visible}.rl-floorplan__svg{background-color:rgba(0, 0, 0, 0.3);overflow:hidden}.rl-svg__el--selected{fill:var(--mdc-theme-secondary, #ffdc00)}";
            var Floorplan = exports('rl_floorplan', /** @class */ (function () {
                function class_1(hostRef) {
                    registerInstance(this, hostRef);
                    this.rlElementClicked = createEvent(this, "rlElementClicked", 7);
                    this.rlElementCleared = createEvent(this, "rlElementCleared", 7);
                    /**
                     * The ID of the floorplan to display.
                     */
                    // @Prop() floorId?: string;
                    /**
                     * The height for the SVG element.
                     */
                    this.height = '2400';
                    /**
                     * The width for the SVG element.
                     */
                    this.width = '4800';
                    /**
                     * Setting to use the orthographic variant of the floorplan.
                     */
                    this.useOrtho = false;
                    /**
                     * Setting to true adds a viewbox attribute to the SVG element.
                     */
                    this.useViewbox = false;
                    /**
                     * The width of the SVG viewbox.
                     */
                    this.vbHeight = this.height;
                    /**
                     * The height of the SVG viewbox.
                     */
                    this.vbWidth = this.width;
                }
                class_1.prototype.render = function () {
                    var _this = this;
                    var elements = this.svgData !== undefined
                        ? this.svgData
                        : [{
                                elem: 'text',
                                prefix: '',
                                local: 'text',
                                attrs: {
                                    style: 'font-size: 72px; text-anchor: middle;',
                                    x: '50%',
                                    y: '50%',
                                    id: 'placeholder-svg'
                                },
                                content: [{
                                        text: 'No SVG Specified',
                                    }],
                                type: 'text'
                            }];
                    return (h(Host, { class: "rl-floorplan" }, h("svg", { width: this.width, height: this.height, viewBox: this.useViewbox ? "0 0 " + this.vbWidth + " " + this.vbHeight : undefined, class: "rl-floorplan__svg", onClick: function (e) {
                            if (e.target instanceof SVGElement && e.target.classList.contains('rl-clickable')) {
                                _this.rlElementClicked.emit(e.target.id);
                            }
                            else {
                                _this.rlElementCleared.emit();
                            }
                        } }, h(SVGDefs, null), h("g", null, h(SVGContent, { elements: elements, extra: this.extraElementData })))));
                };
                return class_1;
            }()));
            Floorplan.style = floorplanCss;
        }
    };
});
